@@ -1,7 +1,7 @@
 import celery.decorators
 from celery.task.base import Task
-task = celery.decorators.task
+task = celery.task
 from celery.execute import send_task
 Task = Task
 
-CONFIG = None
\ No newline at end of file
+CONFIG = None
