@@ -1,26 +1,30 @@
 from simplejson.encoder import JSONEncoder
 from datetime import datetime, date, time
 from bson.objectid import ObjectId
-from mongoengine.document import Document
+from bson.dbref import DBRef
+from mongoengine.document import Document, EmbeddedDocument
 from mongoengine.queryset import QuerySet
-from pymongo import dbref
-from mongoengine import base
-import j25
+from mongoengine.connection import get_db
 
 class JSONCustomEncoder(JSONEncoder):
     def default(self, obj):
         if isinstance(obj, QuerySet):
             return list(obj)
-        if isinstance(obj, Document):
-            doc = obj.to_mongo()
+        if isinstance(obj, DBRef):
+            doc = get_db().dereference(obj)
             try:
                 doc.pop('_cls')
                 doc.pop('_types')
             except:
                 pass
             return doc
-        if isinstance(obj, dbref.DBRef):
-            doc = j25._store[obj.collection].find_one({'_id': ObjectId(obj.id)})
+        if isinstance(obj, (Document, EmbeddedDocument)):
+            doc = obj.to_mongo()
+            try:
+                doc.pop('_cls')
+                doc.pop('_types')
+            except:
+                pass
             return doc
         if isinstance(obj, ObjectId):
             return str(obj)
